| Safe Haskell | Safe-Infered |
|---|
System.OpenCL.Wrappers.Errors
Description
A collection of all the error codes that OpenCL functions return
OpenCLWrappers-0.1.0.1: The OpenCL Standard for heterogenous data-parallel computing
| Safe Haskell | Safe-Infered |
|---|
System.OpenCL.Wrappers.Errors
Description
A collection of all the error codes that OpenCL functions return